==> ejc-settlementmanage-impl-3.0.0-20230106.104258-162-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookOtherDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-支出明细-其它
 * 
 * @author generator
 * 
 */
public class SettlementBookOtherDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String deductionsName; // 扣款名称
    private java.lang.String unitsC; // 单位
    private java.math.BigDecimal number; // 数量
    private java.math.BigDecimal extaxUnitpriceC; // 除税单价
    private java.math.BigDecimal intaxUnitpriceC; // 含税单价
    private java.math.BigDecimal extaxPriceC; // 除税金额
    private java.math.BigDecimal intaxPriceC; // 含税金额
    private java.lang.String remarksC; // 单位
    private java.lang.String withholdingOther; // 扣款类型
    private java.lang.String errorMsg; // 错误信息
    private java.lang.String isEditState; // 是否允许编辑
    private java.math.BigDecimal cumExtaxPrice; // 累计除税金额
    private java.math.BigDecimal cumIntaxPrice; // 累计含税金额
    private java.math.BigDecimal curExtaxPrice; // 本期除税金额
    private java.math.BigDecimal curIntaxPrice; // 本期含税金额


    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }

    public String getDeductionsName() {
        return deductionsName;
    }

    public void setDeductionsName(String deductionsName) {
        this.deductionsName = deductionsName;
    }

    public String getUnitsC() {
        return unitsC;
    }

    public void setUnitsC(String unitsC) {
        this.unitsC = unitsC;
    }

    public BigDecimal getNumber() {
        return number;
    }

    public void setNumber(BigDecimal number) {
        this.number = number;
    }

    public BigDecimal getExtaxUnitpriceC() {
        return extaxUnitpriceC;
    }

    public void setExtaxUnitpriceC(BigDecimal extaxUnitpriceC) {
        this.extaxUnitpriceC = extaxUnitpriceC;
    }

    public BigDecimal getIntaxUnitpriceC() {
        return intaxUnitpriceC;
    }

    public void setIntaxUnitpriceC(BigDecimal intaxUnitpriceC) {
        this.intaxUnitpriceC = intaxUnitpriceC;
    }

    public BigDecimal getExtaxPriceC() {
        return extaxPriceC;
    }

    public void setExtaxPriceC(BigDecimal extaxPriceC) {
        this.extaxPriceC = extaxPriceC;
    }

    public BigDecimal getIntaxPriceC() {
        return intaxPriceC;
    }

    public void setIntaxPriceC(BigDecimal intaxPriceC) {
        this.intaxPriceC = intaxPriceC;
    }

    public String getRemarksC() {
        return remarksC;
    }

    public void setRemarksC(String remarksC) {
        this.remarksC = remarksC;
    }

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getIsEditState() {
        return isEditState;
    }

    public void setIsEditState(String isEditState) {
        this.isEditState = isEditState;
    }

    public BigDecimal getCumExtaxPrice() {
        return cumExtaxPrice;
    }

    public void setCumExtaxPrice(BigDecimal cumExtaxPrice) {
        this.cumExtaxPrice = cumExtaxPrice;
    }

    public BigDecimal getCumIntaxPrice() {
        return cumIntaxPrice;
    }

    public void setCumIntaxPrice(BigDecimal cumIntaxPrice) {
        this.cumIntaxPrice = cumIntaxPrice;
    }

    public BigDecimal getCurExtaxPrice() {
        return curExtaxPrice;
    }

    public void setCurExtaxPrice(BigDecimal curExtaxPrice) {
        this.curExtaxPrice = curExtaxPrice;
    }

    public BigDecimal getCurIntaxPrice() {
        return curIntaxPrice;
    }

    public void setCurIntaxPrice(BigDecimal curIntaxPrice) {
        this.curIntaxPrice = curIntaxPrice;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20230322.091825-186-sources.jar: com/ejianc/business/settlementmanage/vo/SettlementBookOtherDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 工程分包结算书子表-支出明细-其它
 * 
 * @author generator
 * 
 */
public class SettlementBookOtherDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long sort; // 序号
    private java.lang.String deductionsName; // 扣款名称
    private java.lang.String unitsC; // 单位
    private java.math.BigDecimal number; // 数量
    private java.math.BigDecimal extaxUnitpriceC; // 除税单价
    private java.math.BigDecimal intaxUnitpriceC; // 含税单价
    private java.math.BigDecimal extaxPriceC; // 除税金额
    private java.math.BigDecimal intaxPriceC; // 含税金额
    private java.lang.String remarksC; // 单位
    private java.lang.String withholdingOther; // 扣款类型
    private java.lang.String errorMsg; // 错误信息
    private java.lang.String isEditState; // 是否允许编辑
    private java.math.BigDecimal cumExtaxPrice; // 累计除税金额
    private java.math.BigDecimal cumIntaxPrice; // 累计含税金额
    private java.math.BigDecimal curExtaxPrice; // 本期除税金额
    private java.math.BigDecimal curIntaxPrice; // 本期含税金额
    private java.lang.String isDeleted; // 是否允许删除

    public String getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(String isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getSort() {
        return sort;
    }

    public void setSort(Long sort) {
        this.sort = sort;
    }

    public String getDeductionsName() {
        return deductionsName;
    }

    public void setDeductionsName(String deductionsName) {
        this.deductionsName = deductionsName;
    }

    public String getUnitsC() {
        return unitsC;
    }

    public void setUnitsC(String unitsC) {
        this.unitsC = unitsC;
    }

    public BigDecimal getNumber() {
        return number;
    }

    public void setNumber(BigDecimal number) {
        this.number = number;
    }

    public BigDecimal getExtaxUnitpriceC() {
        return extaxUnitpriceC;
    }

    public void setExtaxUnitpriceC(BigDecimal extaxUnitpriceC) {
        this.extaxUnitpriceC = extaxUnitpriceC;
    }

    public BigDecimal getIntaxUnitpriceC() {
        return intaxUnitpriceC;
    }

    public void setIntaxUnitpriceC(BigDecimal intaxUnitpriceC) {
        this.intaxUnitpriceC = intaxUnitpriceC;
    }

    public BigDecimal getExtaxPriceC() {
        return extaxPriceC;
    }

    public void setExtaxPriceC(BigDecimal extaxPriceC) {
        this.extaxPriceC = extaxPriceC;
    }

    public BigDecimal getIntaxPriceC() {
        return intaxPriceC;
    }

    public void setIntaxPriceC(BigDecimal intaxPriceC) {
        this.intaxPriceC = intaxPriceC;
    }

    public String getRemarksC() {
        return remarksC;
    }

    public void setRemarksC(String remarksC) {
        this.remarksC = remarksC;
    }

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public String getIsEditState() {
        return isEditState;
    }

    public void setIsEditState(String isEditState) {
        this.isEditState = isEditState;
    }

    public BigDecimal getCumExtaxPrice() {
        return cumExtaxPrice;
    }

    public void setCumExtaxPrice(BigDecimal cumExtaxPrice) {
        this.cumExtaxPrice = cumExtaxPrice;
    }

    public BigDecimal getCumIntaxPrice() {
        return cumIntaxPrice;
    }

    public void setCumIntaxPrice(BigDecimal cumIntaxPrice) {
        this.cumIntaxPrice = cumIntaxPrice;
    }

    public BigDecimal getCurExtaxPrice() {
        return curExtaxPrice;
    }

    public void setCurExtaxPrice(BigDecimal curExtaxPrice) {
        this.curExtaxPrice = curExtaxPrice;
    }

    public BigDecimal getCurIntaxPrice() {
        return curIntaxPrice;
    }

    public void setCurIntaxPrice(BigDecimal curIntaxPrice) {
        this.curIntaxPrice = curIntaxPrice;
    }
}
